@@ -1,4 +1,4 @@
-from abc import ABCMeta, abstractmethod, abstractproperty
+from abc import ABCMeta, abstractmethod
 import re
 import os
 import netCDF4
@@ -103,6 +103,8 @@ class NWPDataAccess(object):
     def save_valid_cache(self, filename, valid_times):
         """
         """
+        if valid_time_cache is not None and not os.path.exists(valid_time_cache):
+            os.makedirs(valid_time_cache)
         filename = os.path.join(valid_time_cache, self.md5_filename(filename))
         if not os.path.exists(filename):
             fileobj = open(filename, "w")
@@ -138,7 +140,7 @@ class NWPDataAccess(object):
         for f, fsize, fage in files:
             cum_size_bytes += fsize
             if (cum_size_bytes > valid_time_cache_max_size_bytes) or \
-                fage > valid_time_cache_max_age_seconds:
+                    fage > valid_time_cache_max_age_seconds:
                 os.remove(f)
                 removed_files += 1
 
@@ -284,8 +286,8 @@ class ECMWFDataAccess(NWPDataAccess):
             m = self._filename_re.match(filename)
             if m:
                 # Extract information from the filename.
-                date = int(m.group(1))
-                time = int(m.group(2))
+                # date = int(m.group(1))
+                # time = int(m.group(2))
                 var = m.group(3)
                 step = int(m.group(4))
                 # dtime = int(m.group(1)+m.group(2))
@@ -424,8 +426,6 @@ class CLAMSDataAccess(NWPDataAccess):
             m = self._filename_re.match(filename)
             if m:
                 # Extract information from the filename.
-                date = int(m.group(1))
-                time = int(m.group(2))
                 step = int(m.group(3))
                 # dtime = int(m.group(1)+m.group(2))
                 dtime = m.group(1) + m.group(2)
